@@ -33,6 +33,9 @@ use Ampache\Module\Authorization\AccessLevelEnum;
 use Ampache\Module\Authorization\AccessTypeEnum;
 use Ampache\Module\Authorization\Check\NetworkCheckerInterface;
 use Ampache\Module\Authorization\GuiGatekeeperInterface;
+use Ampache\Module\Catalog\Catalog_local;
+use Ampache\Module\Catalog\Catalog_remote;
+use Ampache\Module\Catalog\Catalog_subsonic;
 use Ampache\Module\Playback\Stream;
 use Ampache\Module\Playback\Stream_Playlist;
 use Ampache\Module\Statistics\Stats;
@@ -636,16 +639,49 @@ final class PlayAction implements ApplicationActionInterface
                     return null;
                 }
             }
+
+            $catalog      = Catalog::create_from_id($mediaCatalogId);
             $cache_path   = (string)AmpConfig::get('cache_path', '');
             $cache_target = AmpConfig::get('cache_target', '');
             $file_target  = (!empty($cache_target) && $cache_target === $transcode_to)
                 ? Catalog::get_cache_path($media->id, $mediaCatalogId, $cache_path, $cache_target)
                 : null;
+
+            $has_cache = ($file_target !== null && is_file($file_target));
+            if ($catalog && !$has_cache) {
+                if (
+                    ($catalog instanceof Catalog_remote || $catalog instanceof Catalog_subsonic) &&
+                    (bool)AmpConfig::get('cache_remote', false)
+                ) {
+                    $media_file = $catalog->getRemoteStreamingUrl($media);
+                    if ($file_target && $media_file) {
+                        $catalog->cache_catalog_file($file_target, $media_file);
+                    }
+                }
+                if (
+                    $catalog instanceof Catalog_local &&
+                    $file_target &&
+                    $cache_target &&
+                    (bool)AmpConfig::get('cache_' . $cache_target, false)
+                ) {
+                    $catalog->cache_catalog_file($file_target, $media, $cache_target);
+                }
+            }
+
+            if ($has_cache) {
+                $size = Core::get_filesize($file_target);
+                sleep(2);
+                while ($size > 0 && $size !== Core::get_filesize($file_target)) {
+                    $size = Core::get_filesize($file_target);
+                    sleep(2);
+                }
+            }
+
             if (
                 $transcode_cfg != 'never' &&
                 $transcode_to &&
-                ($bitrate === 0 || $bitrate = (int)AmpConfig::get('transcode_bitrate', 128) * 1000) &&
-                ($file_target !== null && is_file($file_target))
+                ($bitrate === 0 || $bitrate === (int)AmpConfig::get('transcode_bitrate', 128) * 1000) &&
+                $has_cache
             ) {
                 $this->logger->debug(
                     'Found pre-cached file {' . $file_target . '}',
@@ -658,16 +694,12 @@ final class PlayAction implements ApplicationActionInterface
                 $streamConfiguration = [
                     'file_path' => $file_target,
                     'file_name' => $media->getFileName(),
-                    'file_size' => Core::get_filesize($file_target),
+                    'file_size' => (($media->file && preg_match('/^https?:\/\//i', $media->file)) || time() - filemtime($file_target) < 30) ? $media->size : Core::get_filesize($file_target),
                     'file_type' => $cache_target,
                 ];
+            } elseif ($catalog === null) {
+                return null;
             } else {
-                // Build up the catalog for our current object
-                $catalog = Catalog::create_from_id($mediaCatalogId);
-                if ($catalog === null) {
-                    return null;
-                }
-
                 // Some catalogs redirect you to the remote url so stop here
                 $remoteStreamingUrl = $catalog->getRemoteStreamingUrl($media);
                 if ($remoteStreamingUrl !== null) {
@@ -875,7 +907,7 @@ final class PlayAction implements ApplicationActionInterface
         if ($transcode) {
             $transcode_settings = $media->get_transcode_settings($transcode_to, $player, $troptions);
             if ($bitrate) {
-                $troptions['bitrate'] = ($maxbitrate > 0 && $maxbitrate < $media_bitrate)
+                $troptions['bitrate'] = ($maxbitrate > 0 && $maxbitrate < $bitrate)
                     ? $maxbitrate
                     : $bitrate;
             }
@@ -924,43 +956,49 @@ final class PlayAction implements ApplicationActionInterface
 
         //$this->logger->debug('troptions ' . print_r($troptions, true), [LegacyLogger::CONTEXT_TYPE => self::class]);
         if ($transcode) {
-            // Content-length guessing if required by the player.
-            // Otherwise it shouldn't be used as we are not really sure about final length when transcoding
-            $transcode_settings = Stream::get_transcode_settings_for_media(
-                $streamConfiguration['file_type'],
-                $transcode_to,
-                $player,
-                $streamConfiguration['file_type'],
-                $troptions
-            );
-            $transcode_to = $transcode_settings['format'] ?? $format;
+            if ($cache_file) {
+                $stream_size = Core::get_filesize($stream_file);
+            } else {
+                // Content-length guessing if required by the player.
+                // Otherwise it shouldn't be used as we are not really sure about final length when transcoding
+                $transcode_settings = Stream::get_transcode_settings_for_media(
+                    $streamConfiguration['file_type'],
+                    $transcode_to,
+                    $player,
+                    $streamConfiguration['file_type'],
+                    $troptions
+                );
+                $transcode_to = $transcode_settings['format'] ?? $format;
 
-            // At this point, the bitrate has already been decided inside Stream::start_transcode
-            // so we just try to emulate that logic here
-            $stream_rate = 0;
-            if (isset($troptions['bitrate'])) {
-                // note that the bitrate transcode option is stored as metric bits i.e. kilobits*1000 instead of kilobits*1024
-                $stream_rate = $troptions['bitrate'] / 1024;
-            } elseif (!empty($transcode_settings)) {
-                $stream_rate = Stream::get_max_bitrate($media, $transcode_settings, $troptions);
-            }
+                // At this point, the bitrate has already been decided inside Stream::start_transcode
+                // so we just try to emulate that logic here
+                $stream_rate = 0;
+                if (isset($troptions['bitrate'])) {
+                    // note that the bitrate transcode option is stored as metric bits i.e. kilobits*1000 instead of kilobits*1024
+                    $stream_rate = $troptions['bitrate'] / 1024;
+                } elseif (!empty($transcode_settings)) {
+                    $stream_rate = Stream::get_max_bitrate($media, $transcode_settings, $troptions);
+                }
 
-            // We always guess MP3 content length even when not required, since that codec calculates properly
-            if ($this->requestParser->getFromRequest('content_length') == 'required' || $transcode_to == 'mp3') {
-                if ($media->time > 0 && $stream_rate > 0) {
-                    $stream_size = (int)(($media->time * $stream_rate * 1024) / 8);
+                // We always guess MP3 content length even when not required, since that codec calculates properly
+                if ($this->requestParser->getFromRequest('content_length') == 'required' || $transcode_to == 'mp3') {
+                    if ($media->time > 0 && $stream_rate > 0) {
+                        $stream_size = (int)(($media->time * $stream_rate * 1024) / 8);
+                    } else {
+                        $this->logger->debug(
+                            'Bad media duration / stream bitrate. Content-length calculation skipped.',
+                            [LegacyLogger::CONTEXT_TYPE => __CLASS__]
+                        );
+                        $stream_size = 0;
+                    }
                 } else {
-                    $this->logger->debug(
-                        'Bad media duration / stream bitrate. Content-length calculation skipped.',
-                        [LegacyLogger::CONTEXT_TYPE => __CLASS__]
-                    );
                     $stream_size = 0;
                 }
-            } else {
-                $stream_size = 0;
             }
         } else {
-            $stream_size = $streamConfiguration['file_size'];
+            $stream_size = ($cache_file)
+                ? Core::get_filesize($stream_file)
+                : $streamConfiguration['file_size'];
         }
 
         if (!is_resource($filepointer)) {
