@@ -31,18 +31,22 @@ interface CollectorModuleInterface
      * @param Art $art
      * @param int $limit
      * @param array{
-     *      mb_albumid?: string,
-     *      artist?: string,
-     *      album?: string,
-     *      cover?: ?string,
-     *      file?: string,
-     *      year_filter?: string,
-     *      search_limit?: int,
-     *  } $data
-     *
-     * @return array
+     *     mb_albumid?: string,
+     *     artist?: string,
+     *     album?: string,
+     *     cover?: ?string,
+     *     file?: string,
+     *     year_filter?: string,
+     *     search_limit?: int,
+     * } $data
+     * @return array<int, array{
+     *     'db'?: int,
+     *     'url'?: string,
+     *     'title'?: string,
+     *     'mime'?: string
+     * }>
      */
-    public function collect(
+    public function collectArt(
         Art $art,
         int $limit = 5,
         array $data = []
