@@ -58,6 +58,8 @@ final class AlbumQuery implements QueryInterface
         'update_gt',
         'update_lt',
         'user_catalog',
+        'user_flag',
+        'user_rating',
     ];
 
     /** @var string[] $sorts */
@@ -196,10 +198,14 @@ final class AlbumQuery implements QueryInterface
                 $filter_sql = " `album`.`id` IN (SELECT `album_id` FROM `album_map` WHERE `album_map`.`object_id` = '" . Dba::escape($value) . "') AND ";
                 break;
             case 'album_artist':
-                $filter_sql = " `album`.`id` IN (SELECT `album_id` FROM `album_map` WHERE `album_map`.`object_id` = '" . Dba::escape($value) . "' AND `album_map`.`object_type` = 'album') AND ";
+                $filter_sql = ($value == 0)
+                    ? " `album`.`id` NOT IN (SELECT `album_id` FROM `album_map` WHERE `album_map`.`object_id` = '" . Dba::escape($value) . "' AND `album_map`.`object_type` = 'album') AND "
+                    : " `album`.`id` IN (SELECT `album_id` FROM `album_map` WHERE `album_map`.`object_id` = '" . Dba::escape($value) . "' AND `album_map`.`object_type` = 'album') AND ";
                 break;
             case 'song_artist':
-                $filter_sql = " `album`.`id` IN (SELECT `album_id` FROM `album_map` WHERE `album_map`.`object_id` = '" . Dba::escape($value) . "' AND `album_map`.`object_type` = 'song') AND ";
+                $filter_sql = ($value == 0)
+                    ? " `album`.`id` NOT IN (SELECT `album_id` FROM `album_map` WHERE `album_map`.`object_id` = '" . Dba::escape($value) . "' AND `album_map`.`object_type` = 'song') AND "
+                    : " `album`.`id` IN (SELECT `album_id` FROM `album_map` WHERE `album_map`.`object_id` = '" . Dba::escape($value) . "' AND `album_map`.`object_type` = 'song') AND ";
                 break;
             case 'add_lt':
                 $query->set_join('LEFT', '`song`', '`song`.`album`', '`album`.`id`', 100);
@@ -225,6 +231,16 @@ final class AlbumQuery implements QueryInterface
             case 'user_catalog':
                 $filter_sql = " `album`.`catalog` IN (" . implode(',', Catalog::get_catalogs('', $query->user_id, true)) . ") AND ";
                 break;
+            case 'user_flag':
+                $filter_sql = ((int)$value === 0)
+                    ? " `album`.`id` NOT IN (SELECT `object_id` FROM `user_flag` WHERE `object_type` = 'album' AND `user` = " . (int)$query->user_id . ") AND "
+                    : " `album`.`id` IN (SELECT `object_id` FROM `user_flag` WHERE `object_type` = 'album' AND `user` = " . (int)$query->user_id . ") AND ";
+                break;
+            case 'user_rating':
+                $filter_sql = ((int)$value === 0)
+                    ? " `album`.`id` NOT IN (SELECT `object_id` FROM `rating` WHERE `object_type` = 'album' AND `user` = " . (int)$query->user_id . ") AND "
+                    : " `album`.`id` IN (SELECT `object_id` FROM `rating` WHERE `object_type` = 'album' AND `user` = " . (int)$query->user_id . " AND `rating` = " . Dba::escape($value) . ") AND ";
+                break;
             case 'catalog_enabled':
                 $query->set_join('LEFT', '`catalog`', '`catalog`.`id`', '`album`.`catalog`', 100);
                 $filter_sql = " `catalog`.`enabled` = '1' AND ";
