@@ -25,6 +25,7 @@ declare(strict_types=0);
 
 namespace Ampache\Module\Util;
 
+use Ampache\Config\AmpConfig;
 use Ampache\Module\System\Plugin\PluginTypeEnum;
 use Ampache\Plugin\PluginGetMetadataInterface;
 use Ampache\Repository\Model\Plugin;
@@ -110,6 +111,8 @@ final class VaInfo implements VaInfoInterface
 
     private const MBID_REGEX = '/[a-z0-9]{8}-[a-z0-9]{4}-[a-z0-9]{4}-[a-z0-9]{4}-[a-z0-9]{12}/';
 
+    private const ISRC_REGEX = '/[A-Z]{2}-?[A-Z0-9]{3}-?\d{2}-?\d{5}/';
+
     public string $encoding = '';
 
     public string $encodingId3v1 = '';
@@ -122,7 +125,7 @@ final class VaInfo implements VaInfoInterface
 
     public array $tags = [];
 
-    /* @var string[] */
+    /** @var string[] */
     public array $gatherTypes = [];
 
     public bool $islocal;
@@ -600,7 +603,7 @@ final class VaInfo implements VaInfoInterface
      *     'file': ?string,
      *     'frame_rate': ?float,
      *     'genre': ?string,
-     *     'isrc': ?string,
+     *     'isrc': ?string[],
      *     'language': ?string,
      *     'lyrics': ?string,
      *     'mb_albumartistid': ?string,
@@ -684,8 +687,11 @@ final class VaInfo implements VaInfoInterface
                 ? $tags['genre']
                 : $info['genre'];
 
+            $info['isrc'] = (!$info['isrc'] && array_key_exists('isrc', $tags) && !empty($tags['isrc']))
+                ? $tags['isrc']
+                : $info['isrc'];
+
             $info['mb_trackid']       = (!$info['mb_trackid'] && array_key_exists('mb_trackid', $tags)) ? trim((string)$tags['mb_trackid']) : $info['mb_trackid'];
-            $info['isrc']             = (!$info['isrc'] && array_key_exists('isrc', $tags)) ? trim((string)$tags['isrc']) : $info['isrc'];
             $info['mb_albumid']       = (!$info['mb_albumid'] && array_key_exists('mb_albumid', $tags)) ? trim((string)$tags['mb_albumid']) : $info['mb_albumid'];
             $info['mb_albumid_group'] = (!$info['mb_albumid_group'] && array_key_exists('mb_albumid_group', $tags)) ? trim((string)$tags['mb_albumid_group']) : $info['mb_albumid_group'];
             $info['mb_artistid']      = (!$info['mb_artistid'] && array_key_exists('mb_artistid', $tags)) ? trim((string)$tags['mb_artistid']) : $info['mb_artistid'];
@@ -803,6 +809,27 @@ final class VaInfo implements VaInfoInterface
         return [];
     }
 
+    /**
+     * parse_isrc_array
+     * Return only valid isrc data
+     * @param string[]|string|null $isrc
+     * @return string[]
+     */
+    public static function parse_isrc_array(array|string|null $isrc): array
+    {
+        if (empty($isrc)) {
+            return [];
+        }
+        if (is_array($isrc)) {
+            $isrc = implode(";", $isrc);
+        }
+        if (preg_match_all(self::ISRC_REGEX, $isrc, $matches)) {
+            return $matches[0];
+        }
+
+        return [];
+    }
+
     /**
      * _get_type
      *
@@ -1232,7 +1259,7 @@ final class VaInfo implements VaInfoInterface
                     $parsed['albumartist'] = $data[0];
                     break;
                 case 'isrc':
-                    $parsed['isrc'] = $data[0];
+                    $parsed['isrc'] = (count($data) > 1) ? self::parse_isrc_array($data) : self::parse_isrc_array($data[0]);
                     break;
                 case 'date':
                     $parsed['year'] = $data[0];
@@ -1285,6 +1312,7 @@ final class VaInfo implements VaInfoInterface
                     $parsed['barcode'] = $data[0];
                     break;
                 case 'catalognumber':
+                case 'catalog_number':
                     $parsed['catalog_number'] = $data[0];
                     break;
                 case 'label':
@@ -1409,7 +1437,7 @@ final class VaInfo implements VaInfoInterface
                         : reset($data);
                     break;
                 case 'isrc':
-                    $parsed['isrc'] = $data[0];
+                    $parsed['isrc'] = (count($data) > 1) ? self::parse_isrc_array($data) : self::parse_isrc_array($data[0]);
                     break;
                 case 'comments':
                     $parsed['comment'] = $data[0];
@@ -1432,6 +1460,7 @@ final class VaInfo implements VaInfoInterface
                     $parsed['barcode'] = $data[0];
                     break;
                 case 'catalognumber':
+                case 'catalog_number':
                     $parsed['catalog_number'] = $data[0];
                     break;
                 case 'label':
@@ -1536,6 +1565,7 @@ final class VaInfo implements VaInfoInterface
                         $parsed['barcode'] = $id3v2['comments']['text'][$txxx['description']];
                         break;
                     case 'catalognumber':
+                    case 'catalog_number':
                         $parsed['catalog_number'] = $id3v2['comments']['text'][$txxx['description']];
                         break;
                     case 'label':
@@ -1544,6 +1574,9 @@ final class VaInfo implements VaInfoInterface
                     case 'version':
                         $parsed['version'] = $id3v2['comments']['text'][$txxx['description']];
                         break;
+                    case 'musicbrainz release track id':
+                        // Skip this tag
+                        break;
                     default:
                         $frame = strtolower($this->trimAscii($txxx['description']));
                         if ($enable_custom_metadata && !isset(self::DEFAULT_INFO[$frame]) && !in_array($frame, $parsed)) {
@@ -1565,7 +1598,7 @@ final class VaInfo implements VaInfoInterface
                     $user = $this->userRepository->findByEmail($popm['email']);
                     if ($user instanceof User) {
                         // Ratings are out of 255; scale it
-                        $parsed['rating'][$user->id] = ((int)$popm['rating']) / 255 * 5;
+                        $parsed['rating'][$user->id] = self::parse_rating((int)$popm['rating']);
                     }
                     continue;
                 }
@@ -1575,7 +1608,7 @@ final class VaInfo implements VaInfoInterface
                     $rating_user = (int) $this->configContainer->get(ConfigurationKeyEnum::RATING_FILE_TAG_USER);
                 }
 
-                $parsed['rating'][$rating_user] = ((int)$popm['rating']) / 255 * 5;
+                $parsed['rating'][$rating_user] = self::parse_rating((int)$popm['rating']);
             }
         }
 
@@ -1673,7 +1706,7 @@ final class VaInfo implements VaInfoInterface
                     $parsed['disksubtitle'] = $data[0];
                     break;
                 case 'isrc':
-                    $parsed['isrc'] = $data[0];
+                    $parsed['isrc'] = (count($data) > 1) ? self::parse_isrc_array($data) : self::parse_isrc_array($data[0]);
                     break;
                 case '©art':
                     $parsed['artist'] = $data[0];
@@ -1695,6 +1728,7 @@ final class VaInfo implements VaInfoInterface
                     $parsed['barcode'] = $data[0];
                     break;
                 case 'catalognumber':
+                case 'catalog_number':
                     $parsed['catalog_number'] = $data[0];
                     break;
                 case 'label':
@@ -1703,6 +1737,9 @@ final class VaInfo implements VaInfoInterface
                 case 'version':
                     $parsed['version'] = $data[0];
                     break;
+                case 'musicbrainz release track id':
+                    // Skip this tag
+                    break;
                 default:
                     $parsed[strtolower($tag)] = $data[0];
                     break;
@@ -1848,6 +1885,35 @@ final class VaInfo implements VaInfoInterface
         return $parsed;
     }
 
+    /**
+     * parse_rating
+     * Convert ratings to 5 stars based on semi standard 255 unit scale
+     */
+    public static function parse_rating(int $value): int
+    {
+        if (!$value) {
+            return 0;
+        }
+
+        if (AmpConfig::get('rating_file_tag_compatibility', false)) {
+            if ($value === 1) {
+                return 1;
+            } elseif ($value <= 64) {
+                return 2;
+            } elseif ($value <= 128) {
+                return 3;
+            } elseif ($value <= 196) {
+                return 4;
+            } elseif ($value <= 255) {
+                return 5;
+            }
+        } else {
+            return (int)($value / 255 * 5);
+        }
+
+        return 0;
+    }
+
     /**
      * _parse_filename
      * This function uses the file and directory patterns to pull out extra tag information.
