@@ -36,15 +36,15 @@ use Ampache\Module\Playback\Scrobble\Scrobbler;
 
 class Ampachelibrefm extends AmpachePlugin implements PluginSaveMediaplayInterface
 {
-    public string $name        = 'Libre.FM';
+    public string $name = 'Libre.FM';
 
-    public string $categories  = 'scrobbling';
+    public string $categories = 'scrobbling';
 
     public string $description = 'Records your played songs to your Libre.FM Account';
 
-    public string $url         = '';
+    public string $url = '';
 
-    public string $version     = '000003';
+    public string $version = '000003';
 
     public string $min_ampache = '360003';
 
@@ -55,9 +55,9 @@ class Ampachelibrefm extends AmpachePlugin implements PluginSaveMediaplayInterfa
 
     private $challenge;
 
-    private string $api_key  = '';
+    private string $api_key = '';
 
-    private string $secret  = '';
+    private string $secret = '';
 
     private string $scheme = 'https';
 
@@ -191,7 +191,7 @@ class Ampachelibrefm extends AmpachePlugin implements PluginSaveMediaplayInterfa
 
         // Create our scrobbler and then queue it
         $scrobbler = new Scrobbler($this->api_key, $this->scheme, $this->api_host, $this->challenge, $this->secret);
-        if (!empty($song->get_artist_fullname()) && !$scrobbler->love($flagged, $song->get_artist_fullname(), (string)$song->title)) {
+        if (!in_array($song->get_artist_fullname(), ['', '0'], true) && !$scrobbler->love($flagged, $song->get_artist_fullname(), (string)$song->title)) {
             debug_event(self::class, 'Error Love Failed: ' . $scrobbler->error_msg, 3);
 
             return;
